@@ -57,18 +57,30 @@ else:
     _import_custom_modules = False
 
 
-dock_widget_area = {'roi_manager': QtCore.Qt.LeftDockWidgetArea,
-                    roi_manager.ModuleGUI: QtCore.Qt.LeftDockWidgetArea,
+dock_widget_area = \
+    {
+        'roi_manager': QtCore.Qt.LeftDockWidgetArea,
+        roi_manager.ModuleGUI: QtCore.Qt.LeftDockWidgetArea,
 
-                    'tiff_io': QtCore.Qt.TopDockWidgetArea,
-                    tiff_io.ModuleGUI: QtCore.Qt.TopDockWidgetArea,
+        'tiff_io': QtCore.Qt.TopDockWidgetArea,
+        tiff_io.ModuleGUI: QtCore.Qt.TopDockWidgetArea,
 
-                    'suite2p_importer': QtCore.Qt.TopDockWidgetArea,
-                    suite2p.ModuleGUI: QtCore.Qt.TopDockWidgetArea,
+        'suite2p_importer': QtCore.Qt.TopDockWidgetArea,
+        suite2p.ModuleGUI: QtCore.Qt.TopDockWidgetArea,
+
+        'stimulus_mapping': QtCore.Qt.BottomDockWidgetArea,
+        stimulus_mapping.ModuleGUI: QtCore.Qt.BottomDockWidgetArea,
+    }
+
+# inscopix importer
+if sys.version_info[1] >= 8:
+    dock_widget_area.update(
+        {
+            'inscopix_importer': QtCore.Qt.TopDockWidgetArea,
+            inscopix_importer.ModuleGUI: QtCore.Qt.TopDockWidgetArea,
+        }
+)
 
-                    'stimulus_mapping': QtCore.Qt.BottomDockWidgetArea,
-                    stimulus_mapping.ModuleGUI: QtCore.Qt.BottomDockWidgetArea
-                    }
 
 # caiman modules
 if configuration.HAS_CAIMAN:
@@ -95,6 +107,14 @@ if configuration.HAS_CAIMAN:
     )
 
 
+file_associations =\
+    {
+        '.tif':     tiff_io.ModuleGUI,
+        '.tiff':    tiff_io.ModuleGUI,
+        '.btf':     tiff_io.ModuleGUI,
+    }
+
+
 class MainWindow(QtWidgets.QMainWindow):
     standard_modules = {'tiff_io': tiff_io.ModuleGUI,
                         'mesfile': mesfile_io.ModuleGUI,
@@ -140,10 +160,12 @@ class MainWindow(QtWidgets.QMainWindow):
         self.ui.actionStimulus_Mapping.triggered.connect(lambda: self.run_module(stimulus_mapping.ModuleGUI))
         self.ui.actionScript_Editor.triggered.connect(lambda: self.run_module(script_editor.ModuleGUI))
 
+        if sys.version_info[1] >= 8:
+            self.ui.actionInscopix_isxd.triggered.connect(lambda: self.run_module(inscopix_importer.ModuleGUI))
+
         if configuration.HAS_TENSORFLOW:
             self.ui.actionNuSeT_Segmentation.triggered.connect(lambda: self.run_module(nuset_segment.ModuleGUI))
 
-
         # TODO: refactor the actions trigger connections so they're automated based on module name
         if configuration.HAS_CAIMAN:
             self.ui.actionCNMF.triggered.connect(lambda: self.run_module(cnmf.ModuleGUI))
@@ -533,8 +555,6 @@ class MainWindow(QtWidgets.QMainWindow):
         else:
             return
 
-        if file.endswith('.tiff') or file.endswith('.tif'):
-            tio = self.get_module('tiff_io')
-            assert isinstance(tio, tiff_io.ModuleGUI)
-            tio.tiff_file_path = file
-            tio.check_meta_path()
+        ext = os.path.splitext(file)[1]
+
+        self.get_module(file_associations[ext]).file_sink(file)
