@@ -1,4 +1,5 @@
-from ...common.configuration import HAS_CAIMAN, HAS_TENSORFLOW
+import sys
+from ...common.configuration import HAS_CAIMAN, HAS_TENSORFLOW#, HAS_ISX
 
 __all__ = [
     'mesfile_io',
@@ -8,7 +9,7 @@ __all__ = [
     'script_editor',
     'suite2p',
     'femtonics_mesc',
-    'exporter'
+    'exporter',
 ]
 
 if HAS_CAIMAN:
@@ -27,3 +28,12 @@ if HAS_TENSORFLOW:
         [
             'nuset_segment',
         ]
+
+if sys.version_info[1] >= 8:
+    __all__ += ['inscopix_importer']
+
+#if HAS_ISX:
+#    __all__ += \
+#    [
+#        'inscopix_importer'
+#    ]
