@@ -125,7 +125,7 @@ def run_single(batch_dir, UUID, output):
         m_els = m_els.astype(np.uint16)
 
     img_out_path = os.path.join(batch_dir, f'{UUID}_mc.tiff')
-    tifffile.imsave(img_out_path, m_els, bigtiff=True, imagej=False, compress=1)
+    tifffile.imsave(img_out_path, m_els, bigtiff=True, imagej=True, compress=1)
     output['output_files'] = [UUID + '_mc.tiff']
 
     output.update({'status': 1, 'bord_px': int(bord_px_els)})
@@ -215,7 +215,7 @@ def run_multi(batch_dir, UUID, output):
         mc_out[:, z, :, :] = m_els
 
     img_out_path = os.path.join(batch_dir, f'{UUID}_mc.tiff')
-    tifffile.imsave(img_out_path, mc_out, bigtiff=True, imagej=False, compress=1)
+    tifffile.imsave(img_out_path, mc_out, bigtiff=True, imagej=True, compress=1)
     output['output_files'] = [f'{UUID}_mc.tiff']
 
     output.update(
